#!/bin/sh

# $Id: bacula_mail_summary.sh,v 1.5 2009/03/26 19:04:11 root Exp $
# $Locker:  $

# This script is to create a summary of the job notifications from bacula
# and send it to people who care.
#
# For it to work, you need to have all Bacula job report
# logging to a file, edit LOGPATH to your setup.
# This should be run after all backup jobs have finished.
# Tested with bacula-2.4.4

# Some improvements by: John Lockard <jlockard@umich.edu>  (University of Michigan - School of Information)
#   Changed Date format to better sort
#   Reformatted Levels to fit better
#   Caught more job completion types
#   Added From addressing to the outgoing email
#   Removed log rotation.  I'll leave that up to a system utility (logrotate)
#   Added partial date to Start and End times to cover long running jobs
# Some improvements by: Andrey Yakovlev <freedom@kiev.farlep.net>  (ISP Farlep)
# Contributed by Andrew J. Millar <andrew@alphajuliet.org.uk>
# Patched by Andrey A. Yakovlev <freedom@kiev.farlep.net>

# Use awk to create the report, pass to column to be
# formatted nicely, then on to mail to be sent to
# people who care.

LOGFILE='/var/log/bacula/standard'

EMAIL_TO="backup-admins@example.com"
EMAIL_FROM="bacula-server@example.com"
#EMAIL_FROM=${EMAIL_TO}
EMAIL_SUBJECT="Bacula Job Summary: `date +'%F - %a'`"

#---------------------------------------------------------------------

awk -F\:\  'BEGIN {
        print "Client Status Type StartTime EndTime Files Bytes"
    }

    /director-dir: New file:/ {
        print $3
    }

    /director-dir: File:/ {
        print $3
    }

    /Client/ {
        CLIENT=$2; sub(/"/, "", CLIENT) ; sub(/".*$/, "", CLIENT)
    }
    /Backup Level/ {
        TYPE=$2 ;
        sub(/,.*$/, "", TYPE)
        sub(/Full \(upgraded from Incremental\)/, "I2F", TYPE);
        sub(/Full \(upgraded from Differential\)/, "D2F", TYPE);
        sub(/Full/, "F", TYPE);
        sub(/Incremental/, "I", TYPE);
        sub(/Differential/, "D", TYPE);
    }
    /Start time/ {
        STARTTIME=$2;
        sub(/-[0-9]* /, "-", STARTTIME)
        sub(/^ */, "", STARTTIME)
        gsub(/ /, "-", STARTTIME)
    }
    /End time/ {
        ENDTIME=$2;
        sub(/-[0-9]* /, "-", ENDTIME)
        sub(/^ */, "", ENDTIME)
        gsub(/ /, "-", ENDTIME)
    }
    /Files Examined/ {
        SDFILES=$2
        SDBYTES=0
    }
    /SD Files Written/ {
        SDFILES=$2
    }
    /SD Bytes Written/ {
        SDBYTES=$2
    }
    /Termination/ {
        TERMINATION=$2 ;
        sub(/Backup/, "", TERMINATION) ;
        gsub(/\*\*\*/, "", TERMINATION) ;
        sub(/Verify OK/, "OK-Verify", TERMINATION) ;
        sub(/OK -- with warnings/, "OK-Warn", TERMINATION) ;
        sub(/Migration OK/, "M-OK", TERMINATION);
        sub(/Migration Error/, "M-Error", TERMINATION);
        sub(/y[ ]/, "y-", TERMINATION) ;
        printf "%s %s %s %s %s %s %s\n", CLIENT,TERMINATION,TYPE,STARTTIME,ENDTIME,SDFILES,SDBYTES}' ${LOGFILE} | \
    column -t -x | \
    mail -s "${EMAIL_SUBJECT}" ${EMAIL_TO} -- -F ${EMAIL_FROM}
#
# That's all folks

